#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 happstack-server
version:              7.9.3
visibility:           public
id:                   happstack-server-7.9.3-Kvm2PkZMIWPGyK5v5m6Qoc
key:                  happstack-server-7.9.3-Kvm2PkZMIWPGyK5v5m6Qoc
license:              BSD-3-Clause
maintainer:           Happstack team <happs@googlegroups.com>
author:               Happstack team, HAppS LLC
homepage:             http://happstack.com
synopsis:             Web related tools and services.
description:
    Happstack Server provides an HTTP server and a rich set of functions for routing requests, handling query parameters, generating responses, working with cookies, serving files, and more. For in-depth documentation see the Happstack Crash Course <http://happstack.com/docs/crashcourse/index.html>

category:             Web, Happstack
abi:                  1f13890b383758d3b968b44f34341a73
exposed:              True
exposed-modules:
    Happstack.Server Happstack.Server.Auth Happstack.Server.Compression
    Happstack.Server.Cookie Happstack.Server.Error
    Happstack.Server.FileServe
    Happstack.Server.FileServe.BuildingBlocks Happstack.Server.I18N
    Happstack.Server.Internal.Compression
    Happstack.Server.Internal.Cookie Happstack.Server.Internal.Handler
    Happstack.Server.Internal.Listen
    Happstack.Server.Internal.LogFormat
    Happstack.Server.Internal.LowLevel
    Happstack.Server.Internal.MessageWrap
    Happstack.Server.Internal.Monads
    Happstack.Server.Internal.Multipart
    Happstack.Server.Internal.RFC822Headers
    Happstack.Server.Internal.Socket
    Happstack.Server.Internal.TimeoutIO
    Happstack.Server.Internal.TimeoutManager
    Happstack.Server.Internal.TimeoutSocket
    Happstack.Server.Internal.Types Happstack.Server.Monads
    Happstack.Server.Response Happstack.Server.Routing
    Happstack.Server.RqData Happstack.Server.SURI
    Happstack.Server.SimpleHTTP Happstack.Server.Types
    Happstack.Server.Validation

hidden-modules:
    Happstack.Server.Internal.Clock Happstack.Server.Internal.LazyLiner
    Happstack.Server.SURI.ParseURI Paths_happstack_server

import-dirs:          /usr/lib/ghc-9.6.6/site-local/happstack-server-7.9.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/happstack-server-7.9.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/happstack-server-7.9.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-happstack-server
hs-libraries:         HShappstack-server-7.9.3-Kvm2PkZMIWPGyK5v5m6Qoc
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-3MnxOO7xl0P127Exi8mxw2
    blaze-html-0.9.2.0-npfK3H1ZuJH9Vz9ywDZve bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5 exceptions-0.10.7
    extensible-exceptions-0.1.1.4-7NlwspXgM9LGnBo916NhuH
    filepath-1.4.300.1 hslogger-1.3.2.0-BIrSd8Hic0SHfRAmfDqIH1
    html-1.0.1.2-yrvyqtjCXbBHvzYDYrrGC
    monad-control-1.0.3.1-E5lxYdZ2T24L5KA6ZxZqUG mtl-2.3.1
    network-3.1.4.0-Ds5DY5mKlnsDQk8HC4tJQL
    network-uri-2.6.4.2-6IsL4l5xPlJ2SbjqeOZPL6 parsec-3.1.16.1
    process-1.6.19.0 sendfile-0.7.11.6-5nkkfw9jvVc13IyNZ0bBgS
    syb-0.7.4-BzNZTTWYfk9HN4YOl0udkE
    system-filepath-0.4.14.1-HGo6eXG2YLW4wsrIgt0LLN text-2.0.2
    threads-0.5.1.8-LkHw34nkyre2xxMruzFKRJ time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-KXWNPb7DK3u8Vr2fZyR0eL unix-2.8.4.0
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1 xhtml-3000.2.2.1
    zlib-0.7.1.0-EYn42Kcbw83G25OrlEVL7c

haddock-interfaces:
    /usr/share/doc/haskell-happstack-server/html/happstack-server.haddock

haddock-html:         /usr/share/doc/haskell-happstack-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

